:py:mod:`user_defined_function_1i1o_worker`
===========================================

.. py:module:: user_defined_function_1i1o_worker


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   user_defined_function_1i1o_worker.initialise
   user_defined_function_1i1o_worker.work_function
   user_defined_function_1i1o_worker.on_end_of_life



Attributes
~~~~~~~~~~

.. autoapisummary::

   user_defined_function_1i1o_worker.current_dir
   user_defined_function_1i1o_worker.current_dir
   user_defined_function_1i1o_worker.need_parameters
   user_defined_function_1i1o_worker.functions_path
   user_defined_function_1i1o_worker.function
   user_defined_function_1i1o_worker.worker_object


.. py:data:: current_dir
   

   

.. py:data:: current_dir
   

   

.. py:data:: need_parameters
   :annotation: = True

   

.. py:data:: functions_path
   :annotation: :str

   

.. py:data:: function
   

   

.. py:function:: initialise(worker_object)


.. py:function:: work_function(data, parameters)


.. py:function:: on_end_of_life()


.. py:data:: worker_object
   

   

